@@ -14,6 +14,7 @@
 #    under the License.
 
 import socket
+import ssl
 import struct
 
 import OpenSSL
@@ -25,8 +26,8 @@ except ImportError:
     from urllib3 import connectionpool
     from urllib3 import poolmanager
 
+from oslo_utils import encodeutils
 import six
-import ssl
 
 from glanceclient.common import utils
 
@@ -50,7 +51,6 @@ except ImportError:
 
 
 from glanceclient import exc
-from glanceclient.openstack.common import strutils
 
 
 def to_bytes(s):
@@ -81,7 +81,7 @@ class HTTPSAdapter(adapters.HTTPAdapter):
         # NOTE(flaper87): Make sure the url is encoded, otherwise
         # python's standard httplib will fail with a TypeError.
         url = super(HTTPSAdapter, self).request_url(request, proxies)
-        return strutils.safe_encode(url)
+        return encodeutils.safe_encode(url)
 
     def cert_verify(self, conn, url, verify, cert):
         super(HTTPSAdapter, self).cert_verify(conn, url, verify, cert)
@@ -141,6 +141,11 @@ class VerifiedHTTPSConnection(HTTPSConnection):
     Note: Much of this functionality can eventually be replaced
           with native Python 3.3 code.
     """
+    # Restrict the set of client supported cipher suites
+    CIPHERS = 'ECDH+AESGCM:DH+AESGCM:ECDH+AES256:DH+AES256:'\
+              'eCDH+AES128:DH+AES:ECDH+3DES:DH+3DES:RSA+AESGCM:'\
+              'RSA+AES:RSA+3DES:!aNULL:!MD5:!DSS'
+
     def __init__(self, host, port=None, key_file=None, cert_file=None,
                  cacert=None, timeout=None, insecure=False,
                  ssl_compression=True):
@@ -149,7 +154,11 @@ class VerifiedHTTPSConnection(HTTPSConnection):
         if six.PY3:
             excp_lst = (TypeError, FileNotFoundError, ssl.SSLError)
         else:
-            excp_lst = ()
+            # NOTE(jamespage)
+            # Accomodate changes in behaviour for pep-0467, introduced
+            # in python 2.7.9.
+            # https://github.com/python/peps/blob/master/pep-0476.txt
+            excp_lst = (TypeError, IOError, ssl.SSLError)
         try:
             HTTPSConnection.__init__(self, host, port,
                                      key_file=key_file,
@@ -231,6 +240,7 @@ class VerifiedHTTPSConnection(HTTPSConnection):
         Set up the OpenSSL context.
         """
         self.context = OpenSSL.SSL.Context(OpenSSL.SSL.SSLv23_METHOD)
+        self.context.set_cipher_list(self.CIPHERS)
 
         if self.ssl_compression is False:
             self.context.set_options(0x20000)  # SSL_OP_NO_COMPRESSION
