@@ -107,6 +107,8 @@ def do_image_update(gc, args):
     utils.print_image(image)
 
 
+@utils.arg('--limit', metavar='<LIMIT>', default=None, type=int,
+           help='Maximum number of images to get.')
 @utils.arg('--page-size', metavar='<SIZE>', default=None, type=int,
            help='Number of images to request in each paginated request.')
 @utils.arg('--visibility', metavar='<VISIBILITY>',
@@ -135,6 +137,8 @@ def do_image_list(gc, args):
     filters = dict([item for item in filter_items if item[1] is not None])
 
     kwargs = {'filters': filters}
+    if args.limit is not None:
+        kwargs['limit'] = args.page_size
     if args.page_size is not None:
         kwargs['page_size'] = args.page_size
 
@@ -254,13 +258,20 @@ def do_image_upload(gc, args):
     image_data = utils.get_data_file(args)
     if args.progress:
         filesize = utils.get_file_size(image_data)
-        image_data = progressbar.VerboseFileWrapper(image_data, filesize)
+        if filesize is not None:
+            # NOTE(kragniz): do not show a progress bar if the size of the
+            # input is unknown (most likely a piped input)
+            image_data = progressbar.VerboseFileWrapper(image_data, filesize)
     gc.images.upload(args.id, image_data, args.size)
 
 
 @utils.arg('id', metavar='<IMAGE_ID>', help='ID of image to delete.')
 def do_image_delete(gc, args):
     """Delete specified image."""
+    image = gc.images.get(args.id)
+    if image and image.status == "deleted":
+        msg = "No image with an ID of '%s' exists." % image.id
+        utils.exit(msg)
     gc.images.delete(args.id)
 
 
